[![Python package](https://github.com/getcuia/ochre/actions/workflows/python-package.yml/badge.svg)](https://github.com/getcuia/ochre/actions/workflows/python-package.yml)

# ochre 🏜️

<img src="banner.jpg" alt="ochre" style="width:500px; height:500px; object-fit: fill; border-radius: 100%;" />

> A down-to-earth approach to colors

ochre is a tiny Python package for working with colors in a pragmatic way. The
focus is on simplicity and ease of use, but also on human perception.

## Features

-   🎨 Focus on [RGB](https://en.wikipedia.org/wiki/RGB_color_model) and
    [HCL](https://en.wikipedia.org/wiki/HCL_color_space) color spaces
-   🖥️ Web color names
-   ♻️ Color conversions that easily integrate with the
    [standard `colorsys` module](https://docs.python.org/3/library/colorsys.html)
-   🗑️ Zero dependencies
-   🐍 Python 3.8+

## Credits

[Photo](banner.jpg) by
[Nicola Carter](https://unsplash.com/@ncarterwilts?utm_source=unsplash&utm_medium=referral&utm_content=creditCopyText)
on
[Unsplash](https://unsplash.com/?utm_source=unsplash&utm_medium=referral&utm_content=creditCopyText).
